#ifndef ABOUTWINDOW_H
#define ABOUTWINDOW_H

#include <QMainWindow>
#include <QtGui>
#include <QtWebKit>
#include <qwebviewselectionsuppressor.h>
#include <QDebug>

namespace Ui {
    class AboutWindow;
}

class AboutWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit AboutWindow(QWidget *parent = 0);
    ~AboutWindow();

private:
    Ui::AboutWindow *ui;
    QWebView *view;
    QWebViewSelectionSuppressor *suppressor;
private slots:
    void setProgressIndicatorOn();
    void setProgressIndicatorOff();
};

#endif // ABOUTWINDOW_H
